@@ -1,5 +1,6 @@
 import numpy as np
 from typing import TypedDict
+from .solvers_abc import ABCSolver
 
 
 class data(TypedDict):
@@ -522,7 +523,6 @@ class PressMassSolver:
 
         state[PressMassSolver.name] = results
 
-
 # Расчёт давлений и напряжений в корпусе снаряда
 class StressSolver:
     name = 'st_stress_solver'
@@ -760,7 +760,6 @@ class SafeFactorSolver:
 
         state[SafeFactorSolver.name] = results
 
-
 # Расчёт толщины дна снаряда
 class BottomThickSolver:
     name = 'st_bottom_thick_solver'
@@ -844,7 +843,6 @@ class BottomThickSolver:
 
         state[BottomThickSolver.name] = results
 
-
 # Расчёт деформации ВСЕХ цилиндрических частей корпуса снаряда (2, 4, 3 сечения)
 class DeformCylSolver:
     name = 'st_deform_cyl_solver'
@@ -905,8 +903,6 @@ class DeformCylSolver:
 
         state[DeformCylSolver.name] = results
 
-
-
 # Расчёт жёсткости и устойчивости ЗП части корпуса
 class RampCorpSolver:
     name = 'st_ramp_corp_solver'
@@ -1006,8 +1002,6 @@ class RampCorpSolver:
 
         state[RampCorpSolver.name] = results
 
-
-
 # Расчёт зоны ведущего пояска
 class BeltZoneSolver:
     name = 'st_belt_zone_solver'
@@ -1367,3 +1361,115 @@ class BeltZoneSolver:
         res['W5_con'] = W5_con
 
         state[BeltZoneSolver.name] = res
+
+class apfsds_strenght_solver_data(TypedDict):
+    m_bt: float # Масса бал наконечника
+    m_pl: float# Масса стабилизатора
+    m_k: float# Масса корпуса
+    m_db: float# Масса ВУ
+    m_fl: float
+    m_total: float
+    l_db: float# Длина гребенки ВУ
+    x_db_0: float# Координата начала ВУ от хвоста
+    x_db_n: float# Координата пояска
+    la: float# Ддина активной части
+    da: float# Диаметр активной части
+    d: float# Калибр орудия
+    p_max: float# Макисмальное давление ПГ
+
+class APFSDStrengthSolver(ABCSolver):
+
+    name = 'apfsds_strenght_solver'
+
+    preprocessed_data: apfsds_strenght_solver_data = dict(
+        m_bt=None,
+        m_pl=None,
+        m_k=None,
+        m_db=None,
+        m_fl=None,
+        m_total=None,
+        l_db=None,
+        x_db_0=None,
+        x_db_n=None,
+        la=None,
+        da=None,
+        d=None,
+        p_max=None
+    )
+
+    def get_Fg_tg(self):
+        p_data = self.preprocessed_data
+        m_db = p_data['m_db']
+        m_fl = p_data['m_fl']
+        m_total = p_data['m_total']
+        s = 0.25 * np.pi * p_data['d'] ** 2
+        sk = 0.25 * np.pi * p_data['da'] ** 2
+        p_max = p_data['p_max']
+
+        Fg = 0.5 * p_max * ((s - 2. * sk) - s * (m_db - m_fl) / m_total)
+        tg = 2. * Fg / (np.pi * p_data['da'] * p_data['l_db'])
+
+        return Fg, tg
+
+    @np.vectorize
+    def get_sigma_x(self, x, Fg):
+        p_data = self.preprocessed_data
+        m_bt = p_data['m_bt']
+        m_pl = p_data['m_pl']
+        m_k = p_data['m_k']
+        m_db = p_data['m_db']
+        m_total = p_data['m_total']
+        la = p_data['la']
+        l_db = p_data['l_db']
+        x_db_0 = p_data['x_db_0']
+        s = 0.25 * np.pi * p_data['d'] ** 2
+        sk = 0.25 * np.pi * p_data['da'] ** 2
+        p_max = p_data['p_max']
+
+        if la >= x > (x_db_0 + l_db):
+            sigma = -(m_bt + (m_k + m_pl) * (1. - x / la)) / m_total
+            sigma *= s * p_max / sk
+            return sigma
+        if (x_db_0 + l_db) >= x > x_db_0:
+            sigma = -(m_bt + (m_k + m_pl) * (1. - x / la)) / m_total
+            sigma *= s * p_max / sk
+            sigma += Fg * (l_db + x_db_0 - x) / (l_db * sk)
+            return sigma
+        if x_db_0 >= x > 0.:
+            sigma = -(m_bt + (m_k + m_pl) * (1. - x / la)) / m_total
+            sigma *= s * p_max / sk
+            sigma += Fg / sk
+            return sigma
+        return 0.
+
+    @np.vectorize
+    def get_sigma_r(self, x):
+        p_data = self.preprocessed_data
+        x_db_n = p_data['x_db_n']
+        p_max = p_data['p_max']
+        if 0. < x < x_db_n:
+            return p_max
+        return 0.
+
+    def run(self, data: dict, global_state: dict):
+        n_points = data['settings'][APFSDStrengthSolver.name]['n_points']
+        x = np.linspace(0., self.preprocessed_data['la'], n_points)
+
+        Fg, tg = self.get_Fg_tg()
+
+        sigma_x = self.get_sigma_x(self, x, Fg)
+        sigma_r = self.get_sigma_r(self, x)
+
+        sigma_t = abs(sigma_x + sigma_r)
+
+        global_state[APFSDStrengthSolver.name] = dict(
+            x_mesh=x,
+            sigma_x=sigma_x,
+            sigma_r=sigma_r,
+            sigma_t=sigma_t,
+            Fg=Fg,
+            tg=tg,
+            sigma_x_max=sigma_x.max(),
+            sigma_r_max=sigma_r.max(),
+            sigma_t_max=sigma_t.max()
+        )
